@@ -3,7 +3,7 @@
    Copyright (C) 2020-2022 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 5.0.0 (2022-05-19)
+   Version: 6.0.1 (2022-05-28)
    Website: http://www.gingerblue.org/
 
  */
@@ -386,7 +386,7 @@ int main(int argc, char **argv)
 	g_signal_connect(G_OBJECT(stream_entry), "clicked",
 			 G_CALLBACK(gb_assistant_apply),
 		         gtk_entry_get_text(GTK_ENTRY(stream_entry)));
-	page[10].widget = gtk_label_new(_("Click to launch HTTP streaming server client"));
+	page[10].widget = gtk_label_new(g_strconcat("You can now upload the recorded Ogg Vorbis file to your account on SoundCloud, Bandcamp or Wordpress:\n\n", gtk_entry_get_text(GTK_ENTRY(recording_entry)), NULL));
 	gtk_entry_set_text(GTK_ENTRY(page[10].widget), "Click Apply");
 	g_signal_connect (GTK_BUTTON(stream_entry), "clicked", G_CALLBACK(gb_assistant_apply), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	g_signal_connect(G_OBJECT(stream_label), "clicked",
